@@ -82,9 +82,7 @@ class Task(ILovePDF):
     https://developer.ilovepdf.com/docs/api-reference#request-workflow
     """
 
-    def __init__(
-        self, public_key: str, tool: str, verbose: bool = False, debug: bool = False
-    ) -> None:
+    def __init__(self, public_key: str, tool: str, debug: bool = False) -> None:
         """
         Args:
             public_key (str): iLovePDF API key.
@@ -93,18 +91,15 @@ class Task(ILovePDF):
                 rotate, protect, pdfa, validatepdfa, htmlpdf, extract. pdf-compressor only
                 supports 'compress'.
                 https://developer.ilovepdf.com/docs/api-reference#process.
-            verbose (bool, optional): How much printing to do. Defaults to False.
             debug (bool, optional): Whether to perform real API requests (consumes quota) or
                 just report what would happen. Defaults to False.
         """
 
         super().__init__(public_key)
 
-        self.verbose = verbose
-
         self.files: Dict[str, str] = {}
         self.download_path = ""
-        self.task = ""
+        self._task_id = ""
 
         # Any resource can be called with a debug option. When true, iLovePDF won't process
         # the request but will output the parameters received by the server.
@@ -118,30 +113,40 @@ class Task(ILovePDF):
         # {filename} = original filename
         # {app} = current processing tool (e.g. compress)
         # https://developer.ilovepdf.com/docs/api-reference#output_filename
-        self.payload: Dict[str, Union[str, bool]] = {
-            "task": self.task,
+        self.process_params: Dict[str, Union[str, bool]] = {
             "tool": tool,
-            "ignore_errors": True,
             "ignore_password": True,
-            "output_filename": "{filename}_{app}",
-            "packaged_filename": "{app}_PDFs",
-            "try_pdf_repair": True,
+            "output_filename": "{filename}-{app}",
+            "packaged_filename": "{app}-PDFs-{n}",
         }
 
         self.start()
 
     def start(self) -> None:
+        """Initiate contact with iLovePDF API to get assigned a working server that will
+        handle ensuing requests.
+        """
 
-        response = self._send_request("get", f"start/{self.tool}")
+        json = self._send_request("get", f"start/{self.tool}").json()
 
-        self.working_server = response.json()["server"]
-        self.task = response.json()["task"]
-        self.payload["task"] = self.task
+        if json:
+            self.working_server = json["server"]
+
+            self._task_id = json["task"]
+
+        else:
+            print(
+                "Warning: Starting this task returned empty JSON response. "
+                "Was likely already started."
+            )
 
     def add_file(self, file_path: str) -> None:
 
+        if not os.path.isfile(file_path):
+            raise FileNotFoundError(f"'{file_path}' does not exist")
+
         if file_path in self.files:
-            raise ValueError(f"File '{file_path}' was already added.")
+            print(f"Warning: File '{file_path}' was already added to this task.")
 
         self.files[file_path] = ""
 
@@ -151,7 +156,10 @@ class Task(ILovePDF):
 
             with open(filename, "rb") as file:
                 response = self._send_request(
-                    "post", "upload", payload={"task": self.task}, files={"file": file}
+                    "post",
+                    "upload",
+                    payload={"task": self._task_id},
+                    files={"file": file},
                 )
 
             self.files[filename] = response.json()["server_filename"]
@@ -177,7 +185,10 @@ class Task(ILovePDF):
 
         self.upload()
 
-        payload = {**self.payload}
+        payload: Dict[str, Union[str, bool]] = {
+            **self.process_params,
+            "task": self._task_id,
+        }
 
         for idx, (filename, server_filename) in enumerate(self.files.items()):
 
@@ -192,16 +203,12 @@ class Task(ILovePDF):
 
             print(response)
 
-    def set_output_folder(self, path: str) -> None:
+    def set_outdir(self, path: str) -> None:
 
         os.makedirs(path, exist_ok=True)
 
         self.download_path = path
 
-    def clean_filename(self, filename: str) -> str:
-
-        return "_".join(filename.split("_")[1:])
-
     def download(self) -> Union[str, None]:
 
         if self.debug:
@@ -213,17 +220,20 @@ class Task(ILovePDF):
             )
             return None
 
-        endpoint = f"download/{self.task}"
+        endpoint = f"download/{self._task_id}"
 
         response = self._send_request("get", endpoint, stream=True)
 
-        if self.verbose:
-            print("Downloading processed file(s)...")
-
         # content disposition is something like 'attachment; filename="some_file_compress.pdf"'
         # so split('"')[-2] should get us "some_file_compress.pdf"
         filename = response.headers["content-disposition"].split('"')[-2]
 
+        if not filename:
+            raise ValueError(
+                f"{filename=} after parsing {response.headers['content-disposition']=}, "
+                "expected non-empty string"
+            )
+
         with open(f"{self.download_path}/{filename}", "wb") as f:
             for chunk in response.iter_content(10):
                 f.write(chunk)
@@ -232,7 +242,7 @@ class Task(ILovePDF):
 
     def delete_current_task(self) -> None:
 
-        self._send_request("post", f"task/{self.task}")
+        self._send_request("post", f"task/{self._task_id}")
 
     def get_task_information(self) -> requests.Response:
         """Get task status information.
@@ -243,19 +253,19 @@ class Task(ILovePDF):
         Returns:
             Response: request response object
         """
-        return self._send_request("get", f"task/{self.task}")
+        return self._send_request("get", f"task/{self._task_id}")
 
 
 class Compress(Task):
     """Use the iLovePDF compression tool.
 
     Example:
-        from pypdf_compress import Compress
+        from pdf_compressor import Compress
 
         task = Compress('public_key')
         task.add_file('pdf_file')
-        task.set_output_folder('output_directory')
-        task.execute()
+        task.set_outdir('output_dir')
+        task.process()
         task.download()
         task.delete_current_task()
     """
@@ -267,14 +277,13 @@ class Compress(Task):
         Args:
             public_key (str): iLovePDF public API key. Get yours by signing up at
                 https://developer.ilovepdf.com/signup.
-            compression_level (str, optional): How hard to try to squeeze the file size.
-                'extreme' noticeably degrades image quality. Defaults to "recommended".
+            compression_level (str, optional): How hard to squeeze the file size.
+                'extreme' noticeably degrades image quality. Defaults to 'recommended'.
         """
         super().__init__(public_key, tool="compress", **kwargs)
 
-        self.payload["compression_level"] = compression_level
+        assert compression_level in (
+            valid_levels := ("low", "recommended", "extreme")
+        ), f"Invalid {compression_level=}, must be one of {valid_levels}"
 
-        valid_lvls = ("low", "recommended", "extreme")
-        assert (
-            compression_level in valid_lvls
-        ), f"Invalid {compression_level=}, must be one of {valid_lvls}"
+        self.process_params["compression_level"] = compression_level
