@@ -2,17 +2,21 @@ import os
 import sys
 from argparse import ArgumentParser
 from importlib.metadata import version
-from os.path import exists, expanduser, getsize, relpath, split
+from os.path import expanduser, getsize, relpath, split
 from typing import Sequence
 
-from .ilovepdf import Compress, ILovePDF
-from .utils import ROOT, load_dotenv, sizeof_fmt
+from pdf_compressor.ilovepdf import Compress, ILovePDF
+from pdf_compressor.utils import ROOT, load_dotenv, sizeof_fmt
+
+
+DEFAULT_SUFFIX = "-compressed"
 
 
 def main(argv: Sequence[str] = None) -> int:
 
     parser = ArgumentParser(
-        "PyDF Compress", description="Batch compress PDFs powered by iLovePDF.com"
+        "PDF Compressor",
+        description="Batch compress PDFs on the command line. Powered by iLovePDF.com.",
     )
 
     parser.add_argument(
@@ -29,6 +33,15 @@ def main(argv: Sequence[str] = None) -> int:
 
     parser.add_argument("filenames", nargs="*", help="List of PDF files to compress.")
 
+    parser.add_argument(
+        "--compression-level",
+        "--cl",
+        choices=("low", "recommended", "extreme"),
+        default="recommended",
+        help="How hard to squeeze the file size. 'extreme' noticeably degrades image quality. "
+        "Defaults to 'recommended'.",
+    )
+
     parser.add_argument(
         "-i",
         "--inplace",
@@ -39,7 +52,7 @@ def main(argv: Sequence[str] = None) -> int:
     parser.add_argument(
         "-s",
         "--suffix",
-        default="-compressed",
+        default=DEFAULT_SUFFIX,
         help="String to append to the filename of compressed PDFs. Mutually exclusive with "
         "--inplace flag.",
     )
@@ -51,14 +64,14 @@ def main(argv: Sequence[str] = None) -> int:
         "received by the server..",
     )
 
-    tb_version = version("pdf_compressor")
+    tb_version = version("pdf-compressor")
 
     parser.add_argument(
         "-v", "--version", action="version", version=f"%(prog)s v{tb_version}"
     )
     args = parser.parse_args(argv)
 
-    if (api_key := args.set_api_key) :
+    if api_key := args.set_api_key:
 
         assert api_key.startswith(
             "project_public_"
@@ -83,31 +96,35 @@ def main(argv: Sequence[str] = None) -> int:
 
         return 0
 
-    # if filenames received as command line arguments are relative paths,
-    # convert to absolute paths
-    paths = [a if a.startswith("/") else f"{os.getcwd()}/{a}" for a in args.filenames]
-    # Keep only paths pointing to PDFs that exist.
-    pdfs = [p for p in paths if p.endswith(".pdf") and exists(p)]
+    assert args.inplace or args.suffix, (
+        "Files must either be compressed in-place (--inplace) or you must specify a non-empty "
+        "suffix to append to the name of compressed files."
+    )
 
-    assert (
-        pdfs
-    ), f"Invalid arguments, files must be PDFs, got {len(paths)} files without .pdf extension."
+    pdfs = [file for file in args.filenames if file.lower().endswith(".pdf")]
+    not_pdfs = [file for file in args.filenames if not file.lower().endswith(".pdf")]
 
-    print(f"{len(pdfs)} PDFs to be compressed with iLovePDF:")
+    assert len(not_pdfs) == 0, (
+        f"Input files must be PDFs, got {len(not_pdfs)} files without .pdf "
+        f"extension: {', '.join(not_pdfs)}"
+    )
+
+    print(f"PDFs to be compressed with iLovePDF: {len(pdfs)}")
     for pdf in pdfs:
         print(f"- {relpath(pdf, expanduser('~'))}")
 
     trash_path = f"{expanduser('~')}/.Trash"
 
-    task = Compress(api_key, debug=args.debug)
-
     for idx, pdf_path in enumerate(pdfs, 1):
+        task = Compress(
+            api_key, compression_level=args.compression_level, debug=args.debug
+        )
 
         task.add_file(pdf_path)
 
         dir_name, pdf_name = split(pdf_path)
 
-        task.set_output_folder(dir_name)
+        task.set_outdir(dir_name)
 
         task.process()
         compressed_pdf_name = task.download()
@@ -124,25 +141,34 @@ def main(argv: Sequence[str] = None) -> int:
         diff = orig_size - compressed_size
         if diff > 0:
             percent_diff = 100 * diff / orig_size
+
             print(
                 f"{idx}/{len(pdfs)} Compressed PDF '{pdf_name}' is {sizeof_fmt(diff)} "
                 f"({percent_diff:.2g} %) smaller than the original "
-                f"({sizeof_fmt(compressed_size)} vs {sizeof_fmt(orig_size)}). Using "
-                "compressed file."
+                f"({sizeof_fmt(compressed_size)} vs {sizeof_fmt(orig_size)})."
             )
 
             if args.inplace:
-                if sys.platform == "darwin":  # move file to trash on macOS
-                    print("Old file moved to trash.\n")
+                # move original PDF file to trash on macOS (for later retrieval if necessary)
+                # simply let os.rename() overwrite existing PDF on other platforms
+                if sys.platform == "darwin":
+                    print("Using compressed file. Old file moved to trash.\n")
                     os.rename(pdf_path, f"{trash_path}/{pdf_name}")
-                else:  # simply delete it on other platforms
-                    print("Old file deleted.\n")
-                    os.remove(pdf_path)
 
                 os.rename(compressed_pdf_path, pdf_path)
 
-            else:
-                # TODO: implement adding suffix to compressed PDF file name
+            elif args.suffix:
+                path_name, ext = os.path.splitext(pdf_path)
+                new_path = f"{path_name}{args.suffix}{ext}"
+
+                if os.path.isfile(new_path):
+                    counter = 2
+                    while os.path.isfile(f"{path_name}{args.suffix}-{counter}{ext}"):
+                        counter += 1
+                    new_path = f"{path_name}{args.suffix}-{counter}{ext}"
+
+                pdf_path = new_path
+
                 os.rename(compressed_pdf_path, pdf_path)
 
         else:
